"""
SBMLLayout — clean API for the SBML Layout extension.

Quick start::

    import SBMLLayout as sl

    layout = sl.Layout(sbml_string)
    layout.addNode('S1', x=160, y=100, w=50, h=45)
    layout.addNode('A',  x=60,  y=200, w=50, h=40)
    layout.addNode('A',  x=280, y=300, w=50, h=40, alias=True)
    layout.addReaction('J1', center=(184, 205),
                       reactants=['S1'], products=['S2', 'A'])
    layout.addReaction('J2', center=(185, 346),
                       reactants=['S2', 'A:1'], products=['S3'])
    sbml = layout.toSBML()
"""

from .layout import Layout

__version__ = '0.2.0'
__all__ = ['Layout']



from setuptools import setup, find_packages

setup(
    name='SBMLLayout',
    version='0.2.0',
    description='Clean API for reading and writing the SBML Layout extension',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Herbert Sauro',
    packages=['SBMLLayout'],          # explicit, not find_packages()
    package_dir={'SBMLLayout': 'SBMLLayout'},
    python_requires='>=3.8',
    install_requires=['python-libsbml'],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
    ],
)
